
*******************************************************************************************************************
************************             ALL INCIDENTS DATA
*******************************************************************************************************************

use 		"$DataProc/Version 1\incidents_all.dta", clear


****************** Figure 2

asdoc tab 		year, title(Figure 2) replace save(Results.doc) 

graph bar (count), over(year)
graph export "$WorkDesc\Figure2.png", replace


****************** Figure 3

asdoc tab 		pscgprovince, title(Figure 3)

sort pscgprovince
graph hbar (count), over(pscgprovince, sort(1) descending)
graph export "$WorkDesc\Figure3.png", replace


****************** Figure 4

****	Land-related, non-land  related, undetermined

rename 		incident_cause incident_

gen 		cat_causes=3 
replace 	cat_causes=1 if incident_==7004 
replace 	cat_causes=2 if incident_==9001 |  incident_==-98
label 		define cat_causes 1 "Land-related" 2 "Undetermined" 3 "Non-land related"
label 		values cat_causes cat_causes

asdoc tab 		cat_, title(Figure 4)
graph hbar (count), over(cat_causes)
graph export "$WorkDesc\Figure4.png", replace


******************* Figure 5

asdoc tab 		year cat_causes, title(Figure 5)
tab cat_causes, gen(cat)
preserve
collapse(sum) cat1 cat3, by(year)
twoway (line cat1 year, yaxis(1)) (line cat3 year, yaxis(2))
graph export "$WorkDesc\Figure5.png", replace
restore

****************** Figure 6
gen 		num=1
collapse 	(sum) num, by(psgcbarangay year)
drop 		if psgcbarangay==""
count
gen 		id= psgcbarangay
isid 		id year
gen 		PH=substr( id,1,2)
gen 		reg=substr(id,3,2)
gen 		prov=substr( id,5,2)
gen 		mun=substr( id,7,2)
gen 		bar=substr( id,9,3)
replace 	reg="19" if reg=="15"
egen 		key=concat(PH reg prov mun bar)

save 		"$DataProc/Version 1\incidents_barangay.dta", replace

use 		"$DataProc/Version 1\merged new data.dta", clear /*one observation per barangay, merge with IP data*/
preserve
destring prv, replace
label 		define	prv 85 "Dinagat Islands" 36	"Lanao del Sur" 67	"Surigao del Norte" 2	"Agusan del Norte" 38	"Maguindanao" 66	"Sulu" 68	"Surigao del Sur" 82	"Davao de Oro" 23	"Davao del Norte" 70	"Tawi-Tawi" 86	"Davao Occidental" 7	"Basilan" 3	"Agusan del Sur" 25	"Davao Oriental" 24	"Davao del Sur"
label       value prv prv
collapse 	(sum) totalips, by(prv)
egen 		sum=total(totalips)
gen 		x =(totalips/sum)*100
graph 		hbar (sum) x, over(prv, sort(1) descending)
graph 		export "$WorkDesc\Figure6.png", replace
restore


**************  Figure 7

merge 		1:m key using "$DataProc/Version 1\incidents_barangay.dta"
keep 		if _m==3
drop 		_m
count
gen 		pop=total_population_20

gen 		percentage_num=(num/pop)*100
gen 		percentage_ips=(totalips/pop)

gen 		ipsp=percentage_ips*100


pwcorr 		percentage_num percentage_ips, star(0.005)

twoway 		(scatter percentage_ips percentage_num, mcolor(%60) mlwidth(0) )  (lfitci percentage_ips percentage_num , fcolor(%30)), ytitle(% IPs) xtitle(% incidents) legend(off)  title("{bf}Scatterplot", pos(11) size(2.75)) scheme(white_tableau) subtitle("%IPs vs %Conflict incidents", pos(11) size(2.5))
graph export "$WorkDesc\Figure7.png", replace


*******************************************************************************************************************
************************             DATAFINAL6
*******************************************************************************************************************


use 		"$DataProc/Version 1\datafinal6.dta", clear


******************* Table 1

asdoc sum 		land noland insidecadt percentage status3 status4 urban active mining central highway precarious relocation moved_in moved_out edu_index svs_index eco_index, sep(50) title(Table 1)


******************* Table 2 and Appendix 1

reg		    land insidecadt, cluster(psgc_barangay) 
outreg2     using "$WorkDesc/results1.xls", label excel bdec(3) bracket ctitle(Land) replace

reg 		land insidecadt i.prov i.year, cluster(psgc_barangay)
outreg2     using "$WorkDesc/results1.xls", label excel bdec(3) bracket ctitle(Land) append

reg 		land  insidecadt poverty  urban active mining i.prov i.year, cluster(psgc_barangay)
outreg2     using "$WorkDesc/results1.xls", label excel bdec(3) bracket ctitle(Land) append

reg 		land  insidecadt poverty  urban active mining central highway  i.prov i.year, cluster(psgc_barangay)
outreg2     using "$WorkDesc/results1.xls", label excel bdec(3) bracket ctitle(Land) append

reg			land  insidecadt poverty  urban active mining central highway precarious relocation moved_in moved_out i.prov i.year, cluster(psgc_barangay)
outreg2     using "$WorkDesc/results1.xls", label excel bdec(3) bracket ctitle(Land) append

reg 		land  insidecadt poverty  urban active mining central highway precarious relocation moved_in moved_out edu_index svs_index eco_index i.prov i.year, cluster(psgc_barangay)
outreg2     using "$WorkDesc/results1.xls", label excel bdec(3) bracket ctitle(Land) append

reg 		noland  insidecadt, cluster(psgc_barangay)
outreg2     using "$WorkDesc/results1.xls", label excel bdec(3) bracket ctitle(No Land) append

reg 		noland insidecadt i.prov i.year, cluster(psgc_barangay)
outreg2     using "$WorkDesc/results1.xls", label excel bdec(3) bracket ctitle(No Land) append

reg 		noland  insidecadt poverty  urban active  mining  i.prov i.year, cluster(psgc_barangay)
outreg2     using "$WorkDesc/results1.xls", label excel bdec(3) bracket ctitle(No Land) append

reg 		noland  insidecadt poverty  urban active  mining central highway  i.prov i.year, cluster(psgc_barangay)
outreg2     using "$WorkDesc/results1.xls", label excel bdec(3) bracket ctitle(No Land) append

reg 		noland  insidecadt poverty  urban active  mining central highway precarious relocation moved_in moved_out i.prov i.year, cluster(psgc_barangay)
outreg2     using "$WorkDesc/results1.xls", label excel bdec(3) bracket ctitle(No Land) append

reg 		noland  insidecadt poverty  urban active  mining central highway precarious relocation moved_in moved_out edu_index svs_index eco_index i.prov i.year, cluster(psgc_barangay)
outreg2     using "$WorkDesc/results1.xls", label excel bdec(3) bracket ctitle(No Land) append


******************* Table 3 and Appendix 1
 
reg 		land  status3 status4, cluster(psgc_barangay) 
outreg2     using "$WorkDesc/results6.xls", label excel bdec(3) bracket ctitle(Land) replace

reg 		land status3 status4  i.prov i.year, cluster(psgc_barangay) 
outreg2     using "$WorkDesc/results6.xls", label excel bdec(3) bracket ctitle(Land) append

reg 		land  status3 status4 poverty urban active mining i.prov i.year, cluster(psgc_barangay)
outreg2     using "$WorkDesc/results6.xls", label excel bdec(3) bracket ctitle(Land) append

reg 		land  status3 status4 poverty urban active mining i.prov i.year central highway, cluster(psgc_barangay)
outreg2     using "$WorkDesc/results6.xls", label excel bdec(3) bracket ctitle(Land) append

reg 		land  status3 status4 poverty urban active mining i.prov i.year central highway precarious relocation moved_in moved_out , cluster(psgc_barangay)
outreg2     using "$WorkDesc/results6.xls", label excel bdec(3) bracket ctitle(Land) append

reg 		land  status3 status4 poverty urban active mining i.prov i.year central highway precarious relocation moved_in moved_out edu_index svs_index eco_index, cluster(psgc_barangay)
outreg2     using "$WorkDesc/results6.xls", label excel bdec(3) bracket ctitle(Land) append

reg 		noland status3 status4, cluster(psgc_barangay)
outreg2     using "$WorkDesc/results6.xls", label excel bdec(3) bracket ctitle(No Land) append

reg 		noland status3 status4  i.prov i.year, cluster(psgc_barangay)
outreg2     using "$WorkDesc/results6.xls", label excel bdec(3) bracket ctitle(No Land) append

reg 		noland  status3 status4 poverty urban active mining i.prov i.year , cluster(psgc_barangay)
outreg2     using "$WorkDesc/results6.xls", label excel bdec(3) bracket ctitle(No Land) append

reg 		noland  status3 status4 poverty urban active mining i.prov i.year central highway , cluster(psgc_barangay)
outreg2     using "$WorkDesc/results6.xls", label excel bdec(3) bracket ctitle(No Land) append 

reg 		noland  status3 status4 poverty urban active mining i.prov i.year central highway precarious relocation moved_in moved_out , cluster(psgc_barangay)
outreg2     using "$WorkDesc/results6.xls", label excel bdec(3) bracket ctitle(No Land) append

reg 		noland  status3 status4 poverty urban active mining i.prov i.year central highway precarious relocation moved_in moved_out edu_index svs_index eco_index, cluster(psgc_barangay)
outreg2     using "$WorkDesc/results6.xls", label excel bdec(3) bracket ctitle(No Land) append


******************* Figure 8 and 9
/*Fig 8. Land related and resource related*/
/*Fig 9. Non resource related, non land related, undetermined*/

tab cat_causes2,gen(cat2)
tab cat_causes,gen(cat)
tab ips_categ,gen(ips)

collapse (sum) cat1 cat21 cat23 cat3 cat2 ips1 ips2 ips3, by(ips_categ)

label var cat1 "land-related"
label var cat21 "resource-related"
label var cat23 "non-resource-related"
label var cat3 "non-land-related"
label var cat2 "undetermined"

table ips_categ, stat(sum cat1 cat21) 

table ips_categ, stat(sum cat23 cat3 cat2)

*Land related*
graph bar (sum) ips1 (sum) ips2 (sum) ips3, over(cat1)
graph export "$WorkDesc\Land.png", replace
*Resource related
graph bar (sum) ips1 (sum) ips2 (sum) ips3, over(cat21)
graph export "$WorkDesc\Resource.png", replace
*non-resource-related
graph bar (sum) ips1 (sum) ips2 (sum) ips3, over(cat23)
graph export "$WorkDesc\Non-resource.png", replace
*non-land-related
graph bar (sum) ips1 (sum) ips2 (sum) ips3, over(cat3)
graph export "$WorkDesc\Non-land.png", replace
*undetermined*
graph bar (sum) ips1 (sum) ips2 (sum) ips3, over(cat2)
graph export "$WorkDesc\Undetermined.png", replace
