***** 	Generating single dataset with IP counts and violence incidents adding ancestral domains
*****	Lucia Madrigal, lmadrigal@worldbank.org
*****	December 2022
*****	Version 3, results are in PPT that was presented to experts
***** 	Added new data from census  April 20, 2023

*******************************************************************************************************************
****	Setting root 
clear
set 	more off
set 	varabbrev on
global 	root = "C:\Users\wb558768\Documents\GitHub\conflict\THE PHILIPPINES"
cd 			"$root"
***		Set paths
** 	Data Paths
global 		DataOrig = "$root\Data\DataOrig\"       
global 		DataProc = "$root\Data\DataProc\"             

** 	Do Paths
global 		DoGen 	 = "$root\DoFiles\DoGen\"       
global 		DoDesc   = "$root\DoFiles\DoDesc\" 
 
** 	Work Path
global 		WorkDesc = "$root\Work\ReDescrip\"

****	Merge

use 		"$DataProc/Version 1\ancestral2.dta", clear   /*Data by incident and barangay*/
drop		if	psgcbarangay==""
duplicates 	drop incident_code, force
count
*43,499
isid 		id incident_code
gen 		PH=substr( id,1,2)
gen 		reg=substr(id,3,2)
gen 		prov=substr( id,5,2)
gen 		mun=substr( id,7,2)
gen 		bar=substr( id,9,3)

replace 	reg="19" if reg=="15"

egen 		key=concat(PH reg prov mun bar)
count

merge 		m:1 key using "$DataProc/Version 1\merged new data.dta", force /*includes more variables from the census*/

keep 		if _m==3
drop 		_m
isid 		incident_code key /*more than one incident by barangay*/
count
save 		"$DataProc/Version 1\datafinal.dta", replace

use 	 	"$DataProc/Version 1\density.dta", clear
drop		if	psgc_barangay==""
gen 		PH=substr( id,1,2)
gen 		reg=substr(id,3,2)
gen 		prov=substr( id,5,2)
gen 		mun=substr( id,7,2)
gen 		bar=substr( id,9,3)
replace 	reg="19" if reg=="15"
egen 		key=concat(PH reg prov mun bar)
count
sort key
by key: 	gen dup=cond(_N==1,0,_n)
tab			dup
drop		if dup==1 | dup==2
count
isid key
merge 		1:m key using "$DataProc/Version 1\datafinal.dta", force
keep 		if _m==3
drop 		_m
save 		"$DataProc/Version 1\datafinal2.dta", replace

use 		"$DataProc/Version 1\poverty.dta", clear
rename codreg reg
rename codprov prov
tostring	reg, replace
tostring    prov, replace
replace 	reg="19" if reg=="15"
merge 		m:m reg prov using "$DataProc/Version 1\datafinal2.dta"
keep 		if _m==3
drop 		_m
count
save 		"$DataProc/Version 1\datafinal3.dta", replace

use 		"$DataProc/Version 1\mining.dta", clear
gen 		PH=substr( id,1,2)
gen 		reg=substr(id,3,2)
gen 		prov=substr( id,5,2)
gen 		mun=substr( id,7,2)
gen 		bar=substr( id,9,3)
replace 	reg="19" if reg=="15"
egen 		key=concat(PH reg prov mun bar)
count

merge 		m:m key using "$DataProc/Version 1\datafinal3.dta", force
drop 		if _m==1
drop 		_m
count
save 		"$DataProc/Version 1\datafinal4.dta", replace

use 		"$DataProc/Version 1\active4ps.dta", clear
drop		if	psgc_barangay==""
gen 		PH=substr( id,1,2)
gen 		reg=substr(id,3,2)
gen 		prov=substr( id,5,2)
gen 		mun=substr( id,7,2)
gen 		bar=substr( id,9,3)
replace 	reg="19" if reg=="15"
egen 		key=concat(PH reg prov mun bar)
count

merge 		m:m key using "$DataProc/Version 1\datafinal4.dta"
keep 		if _m==3
drop 		_m

save 		"$DataProc/Version 1\datafinal5.dta", replace


****	Generating variables

use  		"$DataProc/Version 1\datafinal5.dta", clear

destring 	reg prov, replace
label 		define reg	11 "Davao" 19 "BARMM" 16 "Caraga"
label 		values reg reg 

gen 		status2=(status1=="Registered")
replace 	status2=. if status1==""

gen 		status3=(status1=="Registered")
*replace 	status3=. if status1=="" /*agregue esto y cambia*/

gen 		status4=(status1=="For Registration")
*replace 	status4=. if status1=="" /*agregue esto y cambia*/
gen 		percentage_ips=(totalips/pop)
recode 		insidecadt .=0
gen 		ipsp=percentage_ips*100

gen			year_filed=year(date_filed	)
gen			year_appro=year(date_appro	)

gen 		d=year_app-year_filed

gen 		urban=(pop>=5000)

****	Land-related, non-land  related, undetermined
gen 		cat_causes=3 
replace 	cat_causes=1 if incident_==7004
replace 	cat_causes=2 if incident_==9001 |  incident_==-98
label 		define cat_causes 1 "Land-related" 2 "Undetermined" 3 "Non-land related"
label 		values cat_causes cat_causes

****	Resource-related, non-resource related, undetermined
gen 		cat_causes2=3 
replace 	cat_causes2=1 if incident_==7001 | incident_==7002  | incident_==7003 | incident_==7004 | incident_==7006 | incident_==7007 | incident_==7008 | incident_==7009 | incident_==7010 | incident_==7015 | incident_==7016
replace 	cat_causes2=2 if incident_==9001 | incident_==-98
label 		define cat_causes2 1 "Resource-related" 2 "Undetermined" 3 "Non-resource related"
label 		values cat_causes2 cat_causes2

* Identity related
gen 		identity=(incident_==3001 | incident_==3002 | incident_==3003 | incident_==3004 | incident_==3005 | incident_==3006 | incident_==3007 |incident_==3009 | incident_==3012 | incident_==3015 | incident_==3016)


gen 		ips_categ=1 if percentage_ips>=0 & percentage_ips<.0000000001
replace 	ips_categ=2 if percentage_ips>.0000000001 & percentage_ips<0.2174702
replace 	ips_categ=3 if percentage_ips>0.2174702 & percentage_ips<=1
label 		define ips_categ 1 "No presence" 2 "IP low presence" 3 "IP high presence"
label 		values ips_categ ips_categ

gen 		ips_categ2=1 if percentage_ips>=0.000 & percentage_ips<=.25
replace 	ips_categ2=2 if percentage_ips>0.26 & percentage_ips<=.50
replace 	ips_categ2=3 if percentage_ips>0.51 & percentage_ips<=.75
replace 	ips_categ2=4 if percentage_ips>0.76 & percentage_ips<=1



*****	Gen dependent variables
gen 		land=(cat_causes==1)
gen 		noland=(cat_causes==3)
gen 		undet1=(cat_causes==2)

gen 		resources=(cat_causes2==1)
gen 		noresour=(cat_causes2==3)
gen 		undet2=(cat_causes2==2)

*gen 		interac=ips*insidecadt

gen 		mining=(mining_site_id>0)
replace 	mining=0 if mining_site_id==.



save 		"$DataProc/Version 1\datafinal6.dta", replace


******************************************************************************************************************************

use 		"$DataProc/Version 1\datafinal6.dta", clear

****	Regressions
reg		    land insidecadt, vce(robust)
outreg2     using "$WorkDesc/results3.xls", label excel bdec(3) bracket ctitle(Land) replace

reg 		land insidecadt i.prov i.year, vce(robust)
outreg2     using "$WorkDesc/results3.xls", label excel bdec(3) bracket ctitle(Land) append

reg 		land  insidecadt poverty  urban active mining i.prov i.year, vce(robust)
outreg2     using "$WorkDesc/results3.xls", label excel bdec(3) bracket ctitle(Land) append

reg 		land  insidecadt poverty  urban active mining central highway  i.prov i.year, vce(robust)
outreg2     using "$WorkDesc/results3.xls", label excel bdec(3) bracket ctitle(Land) append

reg		land  insidecadt poverty  urban active mining central highway precarious relocation moved_in moved_out i.prov i.year, vce(robust)
outreg2     using "$WorkDesc/results3.xls", label excel bdec(3) bracket ctitle(Land) append

reg 		land  insidecadt poverty  urban active mining central highway precarious relocation moved_in moved_out edu_index svs_index eco_index i.prov i.year, vce(robust)
outreg2     using "$WorkDesc/results3.xls", label excel bdec(3) bracket ctitle(Land) append

reg 		noland  insidecadt, vce(robust)
outreg2     using "$WorkDesc/results3.xls", label excel bdec(3) bracket ctitle(No Land) append

reg 		noland insidecadt i.prov i.year, vce(robust)
outreg2     using "$WorkDesc/results3.xls", label excel bdec(3) bracket ctitle(No Land) append

reg 		noland  insidecadt poverty  urban active  mining  i.prov i.year, vce(robust)
outreg2     using "$WorkDesc/results3.xls", label excel bdec(3) bracket ctitle(No Land) append

reg 		noland  insidecadt poverty  urban active  mining central highway  i.prov i.year, vce(robust)
outreg2     using "$WorkDesc/results3.xls", label excel bdec(3) bracket ctitle(No Land) append

reg 		noland  insidecadt poverty  urban active  mining central highway precarious relocation moved_in moved_out i.prov i.year, vce(robust)
outreg2     using "$WorkDesc/results3.xls", label excel bdec(3) bracket ctitle(No Land) append

reg 		noland  insidecadt poverty  urban active  mining central highway precarious relocation moved_in moved_out edu_index svs_index eco_index i.prov i.year, vce(robust)
outreg2     using "$WorkDesc/results3.xls", label excel bdec(3) bracket ctitle(No Land) append

******************************************************************************************************************************

***  DPROBIT

****	Regressions
dprobit 	land insidecadt, vce(robust)
outreg2     using "$WorkDesc/results31.xls", label excel bdec(3) bracket ctitle(Land) replace

dprobit 	land insidecadt prov year, vce(robust)
outreg2     using "$WorkDesc/results31.xls", label excel bdec(3) bracket ctitle(Land) append

dprobit 	land  insidecadt poverty  urban active mining prov year, vce(robust)
outreg2     using "$WorkDesc/results31.xls", label excel bdec(3) bracket ctitle(Land) append

dprobit 	land  insidecadt poverty  urban active mining prov year central highway, vce(robust)
outreg2     using "$WorkDesc/results31.xls", label excel bdec(3) bracket ctitle(Land) append

dprobit 	land  insidecadt poverty  urban active mining prov year central highway precarious relocation moved_in moved_out, vce(robust)
outreg2     using "$WorkDesc/results31.xls", label excel bdec(3) bracket ctitle(Land) append

dprobit 	land  insidecadt poverty  urban active mining prov year central highway precarious relocation moved_in moved_out edu_index svs_index eco_index, vce(robust)
outreg2     using "$WorkDesc/results31.xls", label excel bdec(3) bracket ctitle(Land) append

dprobit 	noland  insidecadt, vce(robust)
outreg2     using "$WorkDesc/results31.xls", label excel bdec(3) bracket ctitle(No Land) append

dprobit 	noland insidecadt prov year, vce(robust)
outreg2     using "$WorkDesc/results31.xls", label excel bdec(3) bracket ctitle(No Land) append

dprobit 	noland  insidecadt poverty  urban active  mining prov year, vce(robust)
outreg2     using "$WorkDesc/results31.xls", label excel bdec(3) bracket ctitle(No Land) append

dprobit 	noland  insidecadt poverty  urban active  mining prov year central highway, vce(robust)
outreg2     using "$WorkDesc/results31.xls", label excel bdec(3) bracket ctitle(No Land) append

dprobit 	noland  insidecadt poverty  urban active  mining prov year central highway precarious relocation moved_in moved_out , vce(robust)
outreg2     using "$WorkDesc/results31.xls", label excel bdec(3) bracket ctitle(No Land) append

dprobit 	noland  insidecadt poverty  urban active  mining prov year central highway precarious relocation moved_in moved_out edu_index svs_index eco_index, vce(robust)
outreg2     using "$WorkDesc/results31.xls", label excel bdec(3) bracket ctitle(No Land) append



******************************************************************************************************************************

******************************************************************************************************************************

reg 		land  status3 status4, vce(robust)
outreg2     using "$WorkDesc/results6.xls", label excel bdec(3) bracket ctitle(Land) replace

reg 		land status3 status4  i.prov i.year, vce(robust)
outreg2     using "$WorkDesc/results6.xls", label excel bdec(3) bracket ctitle(Land) append

reg 		land  status3 status4 poverty urban active mining i.prov i.year, vce(robust)
outreg2     using "$WorkDesc/results6.xls", label excel bdec(3) bracket ctitle(Land) append

reg 		land  status3 status4 poverty urban active mining i.prov i.year central highway, vce(robust)
outreg2     using "$WorkDesc/results6.xls", label excel bdec(3) bracket ctitle(Land) append

reg 		land  status3 status4 poverty urban active mining i.prov i.year central highway precarious relocation moved_in moved_out , vce(robust)
outreg2     using "$WorkDesc/results6.xls", label excel bdec(3) bracket ctitle(Land) append

reg 		land  status3 status4 poverty urban active mining i.prov i.year central highway precarious relocation moved_in moved_out edu_index svs_index eco_index, vce(robust)
outreg2     using "$WorkDesc/results6.xls", label excel bdec(3) bracket ctitle(Land) append

reg 		noland status3 status4, vce(robust)
outreg2     using "$WorkDesc/results6.xls", label excel bdec(3) bracket ctitle(No Land) append

reg 		noland status3 status4  i.prov i.year, vce(robust)
outreg2     using "$WorkDesc/results6.xls", label excel bdec(3) bracket ctitle(No Land) append

reg 		noland  status3 status4 poverty urban active mining i.prov i.year , vce(robust)
outreg2     using "$WorkDesc/results6.xls", label excel bdec(3) bracket ctitle(No Land) append

reg 		noland  status3 status4 poverty urban active mining i.prov i.year central highway , vce(robust)
outreg2     using "$WorkDesc/results6.xls", label excel bdec(3) bracket ctitle(No Land) append 

reg 		noland  status3 status4 poverty urban active mining i.prov i.year central highway precarious relocation moved_in moved_out , vce(robust)
outreg2     using "$WorkDesc/results6.xls", label excel bdec(3) bracket ctitle(No Land) append

reg 		noland  status3 status4 poverty urban active mining i.prov i.year central highway precarious relocation moved_in moved_out edu_index svs_index eco_index, vce(robust)
outreg2     using "$WorkDesc/results6.xls", label excel bdec(3) bracket ctitle(No Land) append

****** DPROBIT

dprobit		land  status3 status4, vce(robust)
outreg2     using "$WorkDesc/results61.xls", label excel bdec(3) bracket ctitle(Land) replace

dprobit 	land status3 status4  prov year, vce(robust)
outreg2     using "$WorkDesc/results61.xls", label excel bdec(3) bracket ctitle(Land) append

dprobit		land  status3 status4 poverty urban active mining prov year , vce(robust)
outreg2     using "$WorkDesc/results61.xls", label excel bdec(3) bracket ctitle(Land) append

dprobit		land  status3 status4 poverty urban active mining prov year central highway, vce(robust)
outreg2     using "$WorkDesc/results61.xls", label excel bdec(3) bracket ctitle(Land) append

dprobit		land  status3 status4 poverty urban active mining prov year central highway precarious relocation moved_in moved_out, vce(robust)
outreg2     using "$WorkDesc/results61.xls", label excel bdec(3) bracket ctitle(Land) append

dprobit		land  status3 status4 poverty urban active mining prov year central highway precarious relocation moved_in moved_out edu_index svs_index eco_index, vce(robust)
outreg2     using "$WorkDesc/results61.xls", label excel bdec(3) bracket ctitle(Land) append

dprobit		noland status3 status4, vce(robust)
outreg2     using "$WorkDesc/results61.xls", label excel bdec(3) bracket ctitle(No Land) append

dprobit 	noland status3 status4  prov year, vce(robust)
outreg2     using "$WorkDesc/results61.xls", label excel bdec(3) bracket ctitle(No Land) append

dprobit 	noland  status3 status4 poverty urban active mining prov year, vce(robust)
outreg2     using "$WorkDesc/results61.xls", label excel bdec(3) bracket ctitle(No Land) append

dprobit 	noland  status3 status4 poverty urban active mining prov year central highway , vce(robust)
outreg2     using "$WorkDesc/results61.xls", label excel bdec(3) bracket ctitle(No Land) append

dprobit 	noland  status3 status4 poverty urban active mining prov year central highway precarious relocation moved_in moved_out , vce(robust)
outreg2     using "$WorkDesc/results61.xls", label excel bdec(3) bracket ctitle(No Land) append

dprobit 	noland  status3 status4 poverty urban active mining prov year central highway precarious relocation moved_in moved_out edu_index svs_index eco_index, vce(robust)
outreg2     using "$WorkDesc/results61.xls", label excel bdec(3) bracket ctitle(No Land) append

stop

/*not reported

reg 	land  ips , vce(robust)
outreg2     using "$WorkDesc/results4.xls", label excel bdec(3) bracket ctitle(Land) replace

reg 	land ips  i.codprov i.year, vce(robust)
outreg2     using "$WorkDesc/results4.xls", label excel bdec(3) bracket ctitle(Land) append

reg 	land  ips poverty  urban active mining i.codprov i.year, vce(robust)
outreg2     using "$WorkDesc/results4.xls", label excel bdec(3) bracket ctitle( Land) append

reg 	noland  ips , vce(robust)
outreg2     using "$WorkDesc/results4.xls", label excel bdec(3) bracket ctitle(No Land) append

reg 	noland ips  i.codprov i.year, vce(robust)
outreg2     using "$WorkDesc/results4.xls", label excel bdec(3) bracket ctitle(No Land) append

reg 	noland  ips poverty urban active mining i.codprov i.year, vce(robust)
outreg2     using "$WorkDesc/results4.xls", label excel bdec(3) bracket ctitle(No Land) append

******************************************************************************************************************************
***	interaccion

reg 	land  ips insidecadt interac , vce(robust)
outreg2     using "$WorkDesc/results5.xls", label excel bdec(3) bracket ctitle(Land) replace

reg 	land ips insidecadt interac i.codprov i.year, vce(robust)
outreg2     using "$WorkDesc/results5.xls", label excel bdec(3) bracket ctitle(Land) append

reg 	land  ips insidecadt interac poverty density mining i.codprov i.year, vce(robust)
outreg2     using "$WorkDesc/results5.xls", label excel bdec(3) bracket ctitle(Land) append

reg 	noland  ips insidecadt interac, vce(robust)
outreg2     using "$WorkDesc/results5.xls", label excel bdec(3) bracket ctitle(No Land) append

reg 	noland ips insidecadt interac i.codprov i.year, vce(robust)
outreg2     using "$WorkDesc/results5.xls", label excel bdec(3) bracket ctitle(No Land) append

reg 	noland  ips insidecadt interac poverty density mining i.codprov i.year, vce(robust)
outreg2     using "$WorkDesc/results5.xls", label excel bdec(3) bracket ctitle(No Land) append

******************************************************************************************************************************


reg 	land  d , vce(robust)
outreg2     using "$WorkDesc/results7.xls", label excel bdec(3) bracket ctitle(Land) replace

reg 	land d   i.codprov i.year, vce(robust)
outreg2     using "$WorkDesc/results7.xls", label excel bdec(3) bracket ctitle(Land) append

reg 	land  d poverty active4ps_2020 urban  mining i.codprov i.year, vce(robust)
outreg2     using "$WorkDesc/results7.xls", label excel bdec(3) bracket ctitle(Land) append

reg 	noland d , vce(robust)
outreg2     using "$WorkDesc/results7.xls", label excel bdec(3) bracket ctitle(No Land) append

reg 	noland d   i.codprov i.year, vce(robust)
outreg2     using "$WorkDesc/results7.xls", label excel bdec(3) bracket ctitle(No Land) append

reg 	noland  d poverty active4ps_2020 urban  mining i.codprov i.year, vce(robust)
outreg2     using "$WorkDesc/results7.xls", label excel bdec(3) bracket ctitle(No Land) append


******************************************************************************************************************************


****	Incident categories

gen 		incident_categ=9
replace 	incident_categ=1 if incident_>=8001 & incident_<=8040

replace 	incident_categ=2 if incident_==1001 | incident_==1002 | incident_==1003 | incident_==1004 | incident_==1005 | incident_==1006 | incident_==1007 | incident_==1008 | incident_==1012 | incident_==1013 

replace 	incident_categ=3 if incident_==5001 | incident_==5002 | incident_==5004 | incident_==5005 | incident_==5006 | incident_==5007 | incident_==5008 |incident_==5009 | incident_==5011 | incident_==5012 | incident_==5017

replace 	incident_categ=4 if incident_==3001 | incident_==3002 | incident_==3003 | incident_==3004 | incident_==3005 | incident_==3006 | incident_==3007 |incident_==3009 | incident_==3012 | incident_==3015 | incident_==3016

replace 	incident_categ=5 if incident_==7001 | incident_==7002  | incident_==7003 | incident_==7004 | incident_==7006 | incident_==7007 | incident_==7008 | incident_==7009 | incident_==7010 | incident_==7015 | incident_==7016

replace 	incident_categ=6 if incident_==2001 | incident_==2002 | incident_==2003 | incident_==2004 | incident_==2006 | incident_==2007 | incident_==2008 | incident_==2009 | incident_==2010 | incident_==2011 | incident_==2012 | incident_==2013 | incident_==2014 

label 		define incident_categ 1 "Shadow economies" 2 "Common crimes" 3 "Political issues" 4 "Identity issues" 5 "Resource issues" 6 "Governance issues" 9 "Undetermined"
label 		values incident_categ incident_categ



*/






/*

table ips_categ cat_causes
table ips_categ cat_causes2

*/

****	Regressions
reg		    land insidecadt, cluster(psgc_barangay)
outreg2     using "$WorkDesc/results.xls", label excel bdec(3) bracket ctitle(Land) replace

reg 		land insidecadt i.prov i.year, cluster(psgc_barangay)
outreg2     using "$WorkDesc/results.xls", label excel bdec(3) bracket ctitle(Land) append

reg 		land  insidecadt poverty  urban active mining i.prov i.year, cluster(psgc_barangay)
outreg2     using "$WorkDesc/results.xls", label excel bdec(3) bracket ctitle(Land) append

reg 		land  insidecadt poverty  urban active mining central highway  i.prov i.year, cluster(psgc_barangay)
outreg2     using "$WorkDesc/results.xls", label excel bdec(3) bracket ctitle(Land) append

reg		land  insidecadt poverty  urban active mining central highway precarious relocation moved_in moved_out i.prov i.year, cluster(psgc_barangay)
outreg2     using "$WorkDesc/results.xls", label excel bdec(3) bracket ctitle(Land) append

reg 		land  insidecadt poverty  urban active mining central highway precarious relocation moved_in moved_out edu_index svs_index eco_index i.prov i.year, cluster(psgc_barangay)
outreg2     using "$WorkDesc/results.xls", label excel bdec(3) bracket ctitle(Land) append

reg 		noland  insidecadt, cluster(psgc_barangay)
outreg2     using "$WorkDesc/results.xls", label excel bdec(3) bracket ctitle(No Land) append

reg 		noland insidecadt i.prov i.year, cluster(psgc_barangay)
outreg2     using "$WorkDesc/results.xls", label excel bdec(3) bracket ctitle(No Land) append

reg 		noland  insidecadt poverty  urban active  mining  i.prov i.year, cluster(psgc_barangay)
outreg2     using "$WorkDesc/results.xls", label excel bdec(3) bracket ctitle(No Land) append

reg 		noland  insidecadt poverty  urban active  mining central highway  i.prov i.year, cluster(psgc_barangay)
outreg2     using "$WorkDesc/results.xls", label excel bdec(3) bracket ctitle(No Land) append

reg 		noland  insidecadt poverty  urban active  mining central highway precarious relocation moved_in moved_out i.prov i.year, cluster(psgc_barangay)
outreg2     using "$WorkDesc/results.xls", label excel bdec(3) bracket ctitle(No Land) append

reg 		noland  insidecadt poverty  urban active  mining central highway precarious relocation moved_in moved_out edu_index svs_index eco_index i.prov i.year, cluster(psgc_barangay)
outreg2     using "$WorkDesc/results.xls", label excel bdec(3) bracket ctitle(No Land) append




 
reg 		land  status3 status4, cluster(psgc_barangay) 
outreg2     using "$WorkDesc/results6.xls", label excel bdec(3) bracket ctitle(Land) replace

reg 		land status3 status4  i.prov i.year, cluster(psgc_barangay) 
outreg2     using "$WorkDesc/results6.xls", label excel bdec(3) bracket ctitle(Land) append

reg 		land  status3 status4 poverty urban active mining i.prov i.year, cluster(psgc_barangay)
outreg2     using "$WorkDesc/results6.xls", label excel bdec(3) bracket ctitle(Land) append

reg 		land  status3 status4 poverty urban active mining i.prov i.year central highway, cluster(psgc_barangay)
outreg2     using "$WorkDesc/results6.xls", label excel bdec(3) bracket ctitle(Land) append

reg 		land  status3 status4 poverty urban active mining i.prov i.year central highway precarious relocation moved_in moved_out , cluster(psgc_barangay)
outreg2     using "$WorkDesc/results6.xls", label excel bdec(3) bracket ctitle(Land) append

reg 		land  status3 status4 poverty urban active mining i.prov i.year central highway precarious relocation moved_in moved_out edu_index svs_index eco_index, cluster(psgc_barangay)
outreg2     using "$WorkDesc/results6.xls", label excel bdec(3) bracket ctitle(Land) append

reg 		noland status3 status4, cluster(psgc_barangay)
outreg2     using "$WorkDesc/results6.xls", label excel bdec(3) bracket ctitle(No Land) append

reg 		noland status3 status4  i.prov i.year, cluster(psgc_barangay)
outreg2     using "$WorkDesc/results6.xls", label excel bdec(3) bracket ctitle(No Land) append

reg 		noland  status3 status4 poverty urban active mining i.prov i.year , cluster(psgc_barangay)
outreg2     using "$WorkDesc/results6.xls", label excel bdec(3) bracket ctitle(No Land) append

reg 		noland  status3 status4 poverty urban active mining i.prov i.year central highway , cluster(psgc_barangay)
outreg2     using "$WorkDesc/results6.xls", label excel bdec(3) bracket ctitle(No Land) append 

reg 		noland  status3 status4 poverty urban active mining i.prov i.year central highway precarious relocation moved_in moved_out , cluster(psgc_barangay)
outreg2     using "$WorkDesc/results6.xls", label excel bdec(3) bracket ctitle(No Land) append

reg 		noland  status3 status4 poverty urban active mining i.prov i.year central highway precarious relocation moved_in moved_out edu_index svs_index eco_index, cluster(psgc_barangay)
outreg2     using "$WorkDesc/results6.xls", label excel bdec(3) bracket ctitle(No Land) append
