

use 		"$DataProc/Version 1\ancestral2.dta", clear   /*Data by incident and barangay*/
drop		if	psgcbarangay==""
duplicates 	drop incident_code, force
count
*43,499
isid 		id incident_code
gen 		PH=substr( id,1,2)
gen 		reg=substr(id,3,2)
gen 		prov=substr( id,5,2)
gen 		mun=substr( id,7,2)
gen 		bar=substr( id,9,3)

replace 	reg="19" if reg=="15"

egen 		key=concat(PH reg prov mun bar)
count

merge 		m:1 key using "$DataProc/Version 1\merged new data.dta", force /*includes more variables from the census*/

keep 		if _m==3
drop 		_m
isid 		incident_code key /*more than one incident by barangay*/
count
save 		"$DataProc/Version 1\datafinal.dta", replace

use 	 	"$DataProc/Version 1\density.dta", clear
drop		if	psgc_barangay==""
gen 		PH=substr( id,1,2)
gen 		reg=substr(id,3,2)
gen 		prov=substr( id,5,2)
gen 		mun=substr( id,7,2)
gen 		bar=substr( id,9,3)
replace 	reg="19" if reg=="15"
egen 		key=concat(PH reg prov mun bar)
count
sort key
by key: 	gen dup=cond(_N==1,0,_n)
tab			dup
drop		if dup==1 | dup==2
count
isid key
merge 		1:m key using "$DataProc/Version 1\datafinal.dta", force
keep 		if _m==3
drop 		_m
save 		"$DataProc/Version 1\datafinal2.dta", replace

use 		"$DataProc/Version 1\poverty.dta", clear
rename codreg reg
rename codprov prov
tostring	reg, replace
tostring    prov, replace
replace 	reg="19" if reg=="15"
merge 		m:m reg prov using "$DataProc/Version 1\datafinal2.dta"
keep 		if _m==3
drop 		_m
count
save 		"$DataProc/Version 1\datafinal3.dta", replace

use 		"$DataProc/Version 1\mining.dta", clear
gen 		PH=substr( id,1,2)
gen 		reg=substr(id,3,2)
gen 		prov=substr( id,5,2)
gen 		mun=substr( id,7,2)
gen 		bar=substr( id,9,3)
replace 	reg="19" if reg=="15"
egen 		key=concat(PH reg prov mun bar)
count

merge 		m:m key using "$DataProc/Version 1\datafinal3.dta", force
drop 		if _m==1
drop 		_m
count
save 		"$DataProc/Version 1\datafinal4.dta", replace

use 		"$DataProc/Version 1\active4ps.dta", clear
drop		if	psgc_barangay==""
gen 		PH=substr( id,1,2)
gen 		reg=substr(id,3,2)
gen 		prov=substr( id,5,2)
gen 		mun=substr( id,7,2)
gen 		bar=substr( id,9,3)
replace 	reg="19" if reg=="15"
egen 		key=concat(PH reg prov mun bar)
count

merge 		m:m key using "$DataProc/Version 1\datafinal4.dta"
keep 		if _m==3
drop 		_m

save 		"$DataProc/Version 1\datafinal5.dta", replace


****	Generating variables

use  		"$DataProc/Version 1\datafinal5.dta", clear

destring 	reg prov, replace
label 		define reg	11 "Davao" 19 "BARMM" 16 "Caraga"
label 		values reg reg 

gen 		status2=(status1=="Registered")
replace 	status2=. if status1==""

gen 		status3=(status1=="Registered")
*replace 	status3=. if status1=="" /*agregue esto y cambia*/

gen 		status4=(status1=="For Registration")
*replace 	status4=. if status1=="" /*agregue esto y cambia*/
gen 		percentage_ips=(totalips/pop)
recode 		insidecadt .=0
gen 		ipsp=percentage_ips*100

gen			year_filed=year(date_filed	)
gen			year_appro=year(date_appro	)

gen 		d=year_app-year_filed

gen 		urban=(pop>=5000)

****	Land-related, non-land  related, undetermined
gen 		cat_causes=3 
replace 	cat_causes=1 if incident_==7004
replace 	cat_causes=2 if incident_==9001 |  incident_==-98
label 		define cat_causes 1 "Land-related" 2 "Undetermined" 3 "Non-land related"
label 		values cat_causes cat_causes

****	Resource-related, non-resource related, undetermined
gen 		cat_causes2=3 
replace 	cat_causes2=1 if incident_==7001 | incident_==7002  | incident_==7003 | incident_==7004 | incident_==7006 | incident_==7007 | incident_==7008 | incident_==7009 | incident_==7010 | incident_==7015 | incident_==7016
replace 	cat_causes2=2 if incident_==9001 | incident_==-98
label 		define cat_causes2 1 "Resource-related" 2 "Undetermined" 3 "Non-resource related"
label 		values cat_causes2 cat_causes2

* Identity related
gen 		identity=(incident_==3001 | incident_==3002 | incident_==3003 | incident_==3004 | incident_==3005 | incident_==3006 | incident_==3007 |incident_==3009 | incident_==3012 | incident_==3015 | incident_==3016)


gen 		ips_categ=1 if percentage_ips>=0 & percentage_ips<.0000000001
replace 	ips_categ=2 if percentage_ips>.0000000001 & percentage_ips<0.2174702
replace 	ips_categ=3 if percentage_ips>0.2174702 & percentage_ips<=1
label 		define ips_categ 1 "No presence" 2 "IP low presence" 3 "IP high presence"
label 		values ips_categ ips_categ

gen 		ips_categ2=1 if percentage_ips>=0.000 & percentage_ips<=.25
replace 	ips_categ2=2 if percentage_ips>0.26 & percentage_ips<=.50
replace 	ips_categ2=3 if percentage_ips>0.51 & percentage_ips<=.75
replace 	ips_categ2=4 if percentage_ips>0.76 & percentage_ips<=1



*****	Gen dependent variables
gen 		land=(cat_causes==1)
gen 		noland=(cat_causes==3)
gen 		undet1=(cat_causes==2)

gen 		resources=(cat_causes2==1)
gen 		noresour=(cat_causes2==3)
gen 		undet2=(cat_causes2==2)

*gen 		interac=ips*insidecadt

gen 		mining=(mining_site_id>0)
replace 	mining=0 if mining_site_id==.



save 		"$DataProc/Version 1\datafinal6.dta", replace
